Documentation
¶
Overview ¶
Package recaptcha handles reCaptcha (http://www.google.com/recaptcha) server side validation
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Response ¶
type Response struct {
Success bool `json:"success"`
Score float64 `json:"score"`
Action string `json:"action"`
ChallengeTS time.Time `json:"challenge_ts"`
Hostname string `json:"hostname"`
ErrorCodes []string `json:"error-codes"`
}
Response from recaptcha
type Verifier ¶
type Verifier struct {
APIURL string
Client *http.Client
// contains filtered or unexported fields
}
Verifier allows to verify a recaptcha You can change the API URL and the http.Client (before you start using Verify to avoid race conditions)
func New ¶
New instance with the default URL (https://www.google.com/recaptcha/api/siteverify)
Click to show internal directories.
Click to hide internal directories.